<!--
  Create Qt help collections from Devhelp2 books
  Copyright (C) 2011 Mathias Hasselmann

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU Lesser General Public
  License as published by the Free Software Foundation; either
  version 2.1 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  Lesser General Public License for more details.

  You should have received a copy of the GNU Lesser General Public
  License along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
  MA  02110-1301  USA
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:devhelp="http://www.devhelp.net/book">

  <xsl:param name="namespace" select="'devhelp.net'" />
  <xsl:param name="virtual-folder" select="'devhelp'" />

  <xsl:output format="xml" encoding="UTF-8" />

  <xsl:template match="/devhelp:book">
    <QtHelpProject version="1.0">
      <namespace><xsl:value-of select="concat($namespace, '.', @name, '.', @version)" /></namespace>
      <virtualFolder><xsl:value-of select="$virtual-folder" /></virtualFolder>

      <customFilter name="{@title}">
        <filterAttribute><xsl:value-of select="@name" /></filterAttribute>
        <filterAttribute><xsl:value-of select="@version" /></filterAttribute>
      </customFilter>

      <filterSection>
        <filterAttribute><xsl:value-of select="@name" /></filterAttribute>
        <filterAttribute><xsl:value-of select="@version" /></filterAttribute>

        <toc>
          <section title="{@title}" ref="{@link}">
            <xsl:apply-templates select="devhelp:chapters/devhelp:sub" />
          </section>
        </toc>

        <keywords>
          <xsl:apply-templates select="devhelp:functions/devhelp:keyword" />
        </keywords>

        <files>
          <file>*.html</file>
          <file>*.png</file>
          <file>*.css</file>
        </files>
      </filterSection>
    </QtHelpProject>
  </xsl:template>

  <xsl:template match="devhelp:sub">
    <section title="{@name}" ref="{@link}">
      <xsl:apply-templates select="devhelp:sub" />
    </section>
  </xsl:template>

  <xsl:template match="devhelp:keyword[@name != '']">
    <keyword name="{@name}" ref="{@link}" />
  </xsl:template>
</xsl:stylesheet>
